@@ -3,11 +3,9 @@
 #use "topfind";;
 #require "equeue";;
 
-open Uq_engines
-
 let main() =
   let e = Unixqueue.create_unix_event_system() in
-  let cp = new copier (`Unidirectional(Unix.stdin,Unix.stdout)) e in
+  let _cp = new Uq_transfer.copier (`Unidirectional(Unix.stdin,Unix.stdout)) e in
   Unixqueue.run e
 ;;
 
