@@ -780,7 +780,7 @@ module Message_passing_2 = struct
 
   let run n =
     let t0 = Unix.gettimeofday() in
-    let pool = Netmcore_mempool.create_mempool 16384 in
+    let pool = Netmcore_mempool.create_mempool (80 * 1024) in
     Netmcore.startup
       ~socket_directory:"run_nqueens"
       ~first_process:(fun () ->
@@ -818,6 +818,9 @@ let () =
 
       "-n", Arg.Set_int n,
       "<n>  Set problem size";
+
+      "-debug-sem-emu", Arg.Unit Netsys_sem.force_emulation,
+      "   Emulate anon semaphores via named semaphores"
     ]
     (fun s -> raise(Arg.Bad("Unexpected arg: " ^ s)))
     "usage: nqueens [-n <number>] (-seq | -sht)";
