@@ -25,5 +25,5 @@
 #define HAVE_EPOLL
 #define HAVE_GETIFADDRS
 #define HAVE_GCC_COMPARE_AND_SWAP
-#define HAVE_GPROF
+#undef HAVE_GPROF
 #define HAVE_LOCALE
