@@ -8,6 +8,8 @@
 /* Linux: make all system prototypes available */
 #define _GNU_SOURCE
 
+#define CAML_INTERNALS
+
 /* POSIX: we want POSIX.1-2008 if possible */
 /* #define _XOPEN_SOURCE 700 */
 
@@ -68,6 +70,9 @@
 #include "caml/bigarray.h"
 #include "caml/version.h"
 
+#ifndef Bytes_val
+#define Bytes_val(x) String_val(x)
+#endif
 
 #ifdef HAVE_POLL
 #define CONST_POLLIN POLLIN
@@ -124,7 +129,7 @@ CAMLextern unsigned char * caml_page_table[Pagetable1_size];
 
 /* Stuff from minor_gc.h */
 
-#if OCAML_VERSION < 41000
+#if !defined(OCAML_VERSION) || OCAML_VERSION < 40400
 CAMLextern char *caml_young_start;
 CAMLextern char *caml_young_end;
 struct caml_ref_table {
@@ -145,8 +150,10 @@ CAMLextern struct caml_ref_table caml_ref_table;
 #define CAML_NAME_SPACE
 #include <caml/minor_gc.h>
 #undef CAML_NAME_SPACE
+#ifdef Caml_state_field
 #define caml_ref_table (*(Caml_state_field(ref_table)))
 #endif
+#endif
 
 
 /* Stuff from major_gc.h */
