@@ -1,7 +1,8 @@
-(* $Id: netsys_impl_util.ml 2195 2015-01-01 12:23:39Z gerd $ *)
+(* $Id$ *)
 
 (* this & that *)
 
+open Netsys_types
 
 let rec restart f arg =
   try 
@@ -78,3 +79,21 @@ let mem_sorted_array x a =
     else false
   in
   search 0 (Array.length a)
+
+
+let tbuffer_length =
+  function
+  | `Bytes u
+  | `String u ->
+      Bytes.length u
+  | `Memory u ->
+      Bigarray.Array1.dim u
+
+let tstring_length =
+  function
+  | `Bytes u ->
+      Bytes.length u
+  | `String u ->
+      String.length u
+  | `Memory u ->
+      Bigarray.Array1.dim u
